from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset






T = TypeVar("T", bound="ParserConfig")



@_attrs_define
class ParserConfig:
    """ 
        Attributes:
            skip_duplicates (bool | Unset): Skip files with identical content already in the workspace. Default: False.
     """

    skip_duplicates: bool | Unset = False
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        skip_duplicates = self.skip_duplicates


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if skip_duplicates is not UNSET:
            field_dict["SKIP_DUPLICATES"] = skip_duplicates

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        skip_duplicates = d.pop("SKIP_DUPLICATES", UNSET)

        parser_config = cls(
            skip_duplicates=skip_duplicates,
        )


        parser_config.additional_properties = d
        return parser_config

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
